@@ -51,14 +51,12 @@ class Selenium(Scraper):
 
         url = config.get(section='SELENIUM', key='url')
 
-        print(f'Giuseppe: {url}')
-
         if url is not None:
             self.driver = webdriver.Remote(command_executor=f'{url}', desired_capabilities={'browserName': 'chrome'}, options=options)
-        # elif platform.system() == 'Windows':
-        #     self.driver = webdriver.Chrome(executable_path='c:\chromedriver.exe', options=options)
-        # elif platform.system() == 'Linux':
-        #     self.driver = webdriver.Chrome(executable_path='/chromedriver', options=options)
+        elif platform.system() == 'Windows':
+            self.driver = webdriver.Chrome(executable_path='c:\chromedriver.exe', options=options)
+        elif platform.system() == 'Linux':
+            self.driver = webdriver.Chrome(executable_path='/chromedriver', options=options)
 
         if len(window_size) > 0:
             self.driver.set_window_position(x=0, y=0)
